@@ -47,7 +47,10 @@
 #include "libedataserver/e-source-list.h"
 
 static gboolean
-get_recur_instance (ECalComponent *comp, time_t instance_start, time_t instance_end, gpointer data)
+get_recur_instance (ECalComponent *comp,
+                    time_t instance_start,
+                    time_t instance_end,
+                    gpointer data)
 {
 	GSList **recur_dates = (GSList **) data;
 	gchar *rdate;
@@ -60,7 +63,10 @@ get_recur_instance (ECalComponent *comp, time_t instance_start, time_t instance_
 }
 
 static gboolean
-get_recur_count (ECalComponent *comp, time_t instance_start, time_t instance_end, gpointer data)
+get_recur_count (ECalComponent *comp,
+                 time_t instance_start,
+                 time_t instance_end,
+                 gpointer data)
 {
 	gint *count = (gint *) data;
 
@@ -70,7 +76,8 @@ get_recur_count (ECalComponent *comp, time_t instance_start, time_t instance_end
 }
 
 static icaltimezone *
-resolve_tzid_cb (const gchar *tzid, gpointer data)
+resolve_tzid_cb (const gchar *tzid,
+                 gpointer data)
 {
 	icaltimezone *zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
 
@@ -100,7 +107,9 @@ e_cal_component_get_gw_id (ECalComponent *comp)
 }
 
 static void
-set_categories_for_gw_item (EGwItem *item, GSList *category_names, ECalBackendGroupwise *cbgw)
+set_categories_for_gw_item (EGwItem *item,
+                            GSList *category_names,
+                            ECalBackendGroupwise *cbgw)
 {
 	GHashTable *categories_by_name, *categories_by_id;
 	EGwConnection *cnc;
@@ -146,7 +155,9 @@ set_categories_for_gw_item (EGwItem *item, GSList *category_names, ECalBackendGr
 }
 
 static void
-add_send_options_data_to_item (EGwItem *item, ECalComponent *comp, icaltimezone *default_zone)
+add_send_options_data_to_item (EGwItem *item,
+                               ECalComponent *comp,
+                               icaltimezone *default_zone)
 {
 	const gchar *x_val;
 	const gchar *x_name;
@@ -302,7 +313,7 @@ get_mime_type (const gchar *uri)
 
 static void
 e_cal_backend_groupwise_set_attachments_from_comp (ECalComponent *comp,
-		EGwItem *item)
+                                                   EGwItem *item)
 {
 	GSList *attach_list = NULL, *attach_file_list = NULL;
 	GSList *l;
@@ -359,7 +370,8 @@ e_cal_backend_groupwise_set_attachments_from_comp (ECalComponent *comp,
 
 /* Returns the icalproperty for the Attendee associted with email id */
 static icalproperty *
-get_attendee_prop (icalcomponent *icalcomp, const gchar *attendee)
+get_attendee_prop (icalcomponent *icalcomp,
+                   const gchar *attendee)
 {
 	icalproperty *prop;
 
@@ -379,7 +391,11 @@ get_attendee_prop (icalcomponent *icalcomp, const gchar *attendee)
 /* get_attendee_list from cal comp and convert into
  * egwitemrecipient and set it on recipient_list*/
 static void
-set_attendees_to_item (EGwItem *item, ECalComponent *comp, icaltimezone *default_zone, gboolean delegate, const gchar *user_email)
+set_attendees_to_item (EGwItem *item,
+                       ECalComponent *comp,
+                       icaltimezone *default_zone,
+                       gboolean delegate,
+                       const gchar *user_email)
 {
 	if (e_cal_component_get_vtype (comp) == E_CAL_COMPONENT_JOURNAL) {
 		if  (e_cal_component_has_organizer (comp)) {
@@ -485,7 +501,8 @@ set_attendees_to_item (EGwItem *item, ECalComponent *comp, icaltimezone *default
 }
 
 static gint
-get_actual_count (ECalComponent *comp, ECalBackendGroupwise *cbgw)
+get_actual_count (ECalComponent *comp,
+                  ECalBackendGroupwise *cbgw)
 {
 	gint count = 0;
 	icaltimezone *dzone, *utc;
@@ -502,7 +519,9 @@ get_actual_count (ECalComponent *comp, ECalBackendGroupwise *cbgw)
 }
 
 static void
-set_rrule_from_comp (ECalComponent *comp, EGwItem *item, ECalBackendGroupwise *cbgw)
+set_rrule_from_comp (ECalComponent *comp,
+                     EGwItem *item,
+                     ECalBackendGroupwise *cbgw)
 {
 
 	EGwItemRecurrenceRule *item_rrule;
@@ -583,7 +602,9 @@ set_rrule_from_comp (ECalComponent *comp, EGwItem *item, ECalBackendGroupwise *c
 }
 
 static EGwItem *
-set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBackendGroupwise *cbgw)
+set_properties_from_cal_component (EGwItem *item,
+                                   ECalComponent *comp,
+                                   ECalBackendGroupwise *cbgw)
 {
 	const gchar *uid, *location;
 	gchar *value;
@@ -819,7 +840,9 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 }
 
 EGwItem *
-e_gw_item_new_from_cal_component (const gchar *container, ECalBackendGroupwise *cbgw, ECalComponent *comp)
+e_gw_item_new_from_cal_component (const gchar *container,
+                                  ECalBackendGroupwise *cbgw,
+                                  ECalComponent *comp)
 {
 	EGwItem *item;
 
@@ -838,7 +861,8 @@ e_gw_item_new_from_cal_component (const gchar *container, ECalBackendGroupwise *
 
 /* Set the attendee list and send options to EGwItem */
 EGwItem *
-e_gw_item_new_for_delegate_from_cal (ECalBackendGroupwise *cbgw, ECalComponent *comp)
+e_gw_item_new_for_delegate_from_cal (ECalBackendGroupwise *cbgw,
+                                     ECalComponent *comp)
 {
 	EGwItem *item;
 	icaltimezone *default_zone;
@@ -862,7 +886,8 @@ e_gw_item_new_for_delegate_from_cal (ECalBackendGroupwise *cbgw, ECalComponent *
  * and populate the attach_data
  */
 static gboolean
-get_attach_data_from_server (EGwItemAttachment *attach_item, ECalBackendGroupwise *cbgw)
+get_attach_data_from_server (EGwItemAttachment *attach_item,
+                             ECalBackendGroupwise *cbgw)
 {
 	EGwConnection *cnc;
 	EGwConnectionStatus status;
@@ -885,7 +910,9 @@ get_attach_data_from_server (EGwItemAttachment *attach_item, ECalBackendGroupwis
 }
 
 static void
-set_attachments_to_cal_component (EGwItem *item, ECalComponent *comp, ECalBackendGroupwise *cbgw)
+set_attachments_to_cal_component (EGwItem *item,
+                                  ECalComponent *comp,
+                                  ECalBackendGroupwise *cbgw)
 {
 	GSList *fetch_list = NULL, *l;
 	GSList *comp_attachment_list = NULL;
@@ -926,7 +953,7 @@ set_attachments_to_cal_component (EGwItem *item, ECalComponent *comp, ECalBacken
 				g_free (filename);
 				return; /* Could not get the attachment from the server */
 			}
-			fd = g_open (filename, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
+			fd = g_open (filename, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0600);
 			if (fd == -1) {
 				/* skip gracefully */
 				g_warning ("DEBUG: could not serialize attachments\n");
@@ -1033,7 +1060,9 @@ get_cn_from_display_name (gchar *display_name)
 }
 
 static void
-sanitize_component (ECalComponent *comp, const gchar *server_uid, const gchar *container_id)
+sanitize_component (ECalComponent *comp,
+                    const gchar *server_uid,
+                    const gchar *container_id)
 {
 	icalproperty *icalprop;
 	gint i;
@@ -1042,7 +1071,7 @@ sanitize_component (ECalComponent *comp, const gchar *server_uid, const gchar *c
 	if (server_uid) {
 
 		/* the ID returned by sendItemResponse includes the container ID of the
-		   inbox folder, so we need to replace that with our container ID */
+		 * inbox folder, so we need to replace that with our container ID */
 		for (i = 0; i < strlen (server_uid); i++) {
 			str = g_string_append_c (str, server_uid[i]);
 			if (server_uid[i] == ':') {
@@ -1061,7 +1090,8 @@ sanitize_component (ECalComponent *comp, const gchar *server_uid, const gchar *c
 }
 
 ECalComponent *
-e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
+e_gw_item_to_cal_component (EGwItem *item,
+                            ECalBackendGroupwise *cbgw)
 {
 	ECalComponent *comp;
 	ECalComponentText text;
@@ -1126,7 +1156,7 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 
 			t = e_gw_connection_get_date_from_string (reply_within);
 			temp = ctime (&t);
-			temp[strlen (temp)-1] = '\0';
+			temp[strlen (temp) - 1] = '\0';
 			value = g_strconcat (N_("Reply Requested: by "), temp, "\n\n", mess ? mess : "", NULL);
 			e_gw_item_set_message (item, (const gchar *) value);
 			g_free (value);
@@ -1164,7 +1194,7 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 		itt_utc = icaltime_from_string (t);
 
 		/* RFC 2445 - CREATED/DTSTAMP/LAST-MODIFIED always in UTC */
-		icaltimezone_convert_time (&itt_utc, (icaltimezone*) icaltime_get_timezone (itt_utc), icaltimezone_get_utc_timezone ());
+		icaltimezone_convert_time (&itt_utc, (icaltimezone *) icaltime_get_timezone (itt_utc), icaltimezone_get_utc_timezone ());
 		icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone ());
 
 		e_cal_component_set_created (comp, &itt_utc);
@@ -1175,7 +1205,7 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 	if (t) {
 		itt_utc = icaltime_from_string (t);
 
-		icaltimezone_convert_time (&itt_utc, (icaltimezone*) icaltime_get_timezone (itt_utc), icaltimezone_get_utc_timezone ());
+		icaltimezone_convert_time (&itt_utc, (icaltimezone *) icaltime_get_timezone (itt_utc), icaltimezone_get_utc_timezone ());
 		icaltime_set_timezone (&itt_utc, icaltimezone_get_utc_timezone ());
 
 		e_cal_component_set_last_modified (comp, &itt_utc);
@@ -1443,8 +1473,8 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 					e_cal_component_set_completed (comp, &itt_utc);
 			} else {
 				/* We are setting the completion date as the current time due to
-				   the absence of completion element in the soap interface for posted
-				   tasks */
+				 * the absence of completion element in the soap interface for posted
+				 * tasks */
 				itt = icaltime_today ();
 				e_cal_component_set_completed (comp,&itt);
 			}
@@ -1467,7 +1497,13 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 }
 
 EGwConnectionStatus
-e_gw_connection_send_appointment (ECalBackendGroupwise *cbgw, const gchar *container, ECalComponent *comp, icalproperty_method method, gboolean all_instances, ECalComponent **created_comp, icalparameter_partstat *pstatus)
+e_gw_connection_send_appointment (ECalBackendGroupwise *cbgw,
+                                  const gchar *container,
+                                  ECalComponent *comp,
+                                  icalproperty_method method,
+                                  gboolean all_instances,
+                                  ECalComponent **created_comp,
+                                  icalparameter_partstat *pstatus)
 {
 	EGwConnection *cnc;
 	EGwConnectionStatus status;
@@ -1632,7 +1668,11 @@ e_gw_connection_send_appointment (ECalBackendGroupwise *cbgw, const gchar *conta
 }
 
 EGwConnectionStatus
-e_gw_connection_create_appointment (EGwConnection *cnc, const gchar *container, ECalBackendGroupwise *cbgw, ECalComponent *comp, GSList **id_list)
+e_gw_connection_create_appointment (EGwConnection *cnc,
+                                    const gchar *container,
+                                    ECalBackendGroupwise *cbgw,
+                                    ECalComponent *comp,
+                                    GSList **id_list)
 {
 	EGwItem *item;
 	EGwConnectionStatus status;
@@ -1674,8 +1714,11 @@ e_gw_connection_create_appointment (EGwConnection *cnc, const gchar *container,
 }
 
 static EGwConnectionStatus
-start_freebusy_session (EGwConnection *cnc, const GSList *users,
-               time_t start, time_t end, gchar **session)
+start_freebusy_session (EGwConnection *cnc,
+                        const GSList *users,
+                        time_t start,
+                        time_t end,
+                        gchar **session)
 {
 	SoupSoapMessage *msg;
 	SoupSoapResponse *response;
@@ -1751,7 +1794,8 @@ start_freebusy_session (EGwConnection *cnc, const GSList *users,
 }
 
 static EGwConnectionStatus
-close_freebusy_session (EGwConnection *cnc, const gchar *session)
+close_freebusy_session (EGwConnection *cnc,
+                        const gchar *session)
 {
 	SoupSoapMessage *msg;
 	SoupSoapResponse *response;
@@ -1779,7 +1823,11 @@ close_freebusy_session (EGwConnection *cnc, const gchar *session)
 }
 
 EGwConnectionStatus
-e_gw_connection_get_freebusy_info (ECalBackendGroupwise *cbgw, const GSList *users, time_t start, time_t end, GSList **freebusy)
+e_gw_connection_get_freebusy_info (ECalBackendGroupwise *cbgw,
+                                   const GSList *users,
+                                   time_t start,
+                                   time_t end,
+                                   GSList **freebusy)
 {
 	SoupSoapMessage *msg;
 	SoupSoapResponse *response;
@@ -2022,7 +2070,8 @@ e_gw_connection_get_freebusy_info (ECalBackendGroupwise *cbgw, const GSList *use
 	}G_STMT_END
 
 static void
-set_categories_changes (EGwItem *new_item, EGwItem *old_item)
+set_categories_changes (EGwItem *new_item,
+                        EGwItem *old_item)
 {
 	GList *old_category_list;
 	GList *new_category_list;
@@ -2063,7 +2112,8 @@ set_categories_changes (EGwItem *new_item, EGwItem *old_item)
 }
 
 void
-e_gw_item_set_changes (EGwItem *item, EGwItem *cache_item)
+e_gw_item_set_changes (EGwItem *item,
+                       EGwItem *cache_item)
 {
 	const gchar *subject, *cache_subject;
 	const gchar *message, *cache_message;
@@ -2115,7 +2165,9 @@ e_gw_item_set_changes (EGwItem *item, EGwItem *cache_item)
 }
 
 static void
-add_return_value (EGwSendOptionsReturnNotify track, ESource *source, const gchar *notify)
+add_return_value (EGwSendOptionsReturnNotify track,
+                  ESource *source,
+                  const gchar *notify)
 {
 	gchar *value;
 
@@ -2255,7 +2307,8 @@ e_cal_backend_groupwise_store_settings (GwSettings *hold)
 }
 
 gboolean
-e_cal_backend_groupwise_utils_check_delegate (ECalComponent *comp, const gchar *email)
+e_cal_backend_groupwise_utils_check_delegate (ECalComponent *comp,
+                                              const gchar *email)
 {
 	icalproperty *prop;
 	icalcomponent *icalcomp = e_cal_component_get_icalcomponent (comp);
