@@ -66,7 +66,8 @@ camel_groupwise_journal_init (CamelGroupwiseJournal *groupwise_journal)
 }
 
 static void
-groupwise_entry_free (CamelOfflineJournal *journal, CamelDListNode *entry)
+groupwise_entry_free (CamelOfflineJournal *journal,
+                      CamelDListNode *entry)
 {
 	CamelGroupwiseJournalEntry *groupwise_entry = (CamelGroupwiseJournalEntry *) entry;
 
@@ -77,7 +78,8 @@ groupwise_entry_free (CamelOfflineJournal *journal, CamelDListNode *entry)
 }
 
 static CamelDListNode *
-groupwise_entry_load (CamelOfflineJournal *journal, FILE *in)
+groupwise_entry_load (CamelOfflineJournal *journal,
+                      FILE *in)
 {
 	CamelGroupwiseJournalEntry *entry;
 
@@ -117,7 +119,9 @@ groupwise_entry_load (CamelOfflineJournal *journal, FILE *in)
 }
 
 static gint
-groupwise_entry_write (CamelOfflineJournal *journal, CamelDListNode *entry, FILE *out)
+groupwise_entry_write (CamelOfflineJournal *journal,
+                       CamelDListNode *entry,
+                       FILE *out)
 {
 	CamelGroupwiseJournalEntry *groupwise_entry = (CamelGroupwiseJournalEntry *) entry;
 
@@ -145,7 +149,8 @@ groupwise_entry_write (CamelOfflineJournal *journal, CamelDListNode *entry, FILE
 }
 
 static void
-gw_message_info_dup_to (CamelMessageInfoBase *dest, CamelMessageInfoBase *src)
+gw_message_info_dup_to (CamelMessageInfoBase *dest,
+                        CamelMessageInfoBase *src)
 {
 	camel_flag_list_copy (&dest->user_flags, &src->user_flags);
 	camel_tag_list_copy (&dest->user_tags, &src->user_tags);
@@ -284,7 +289,8 @@ groupwise_entry_play (CamelOfflineJournal *journal,
 }
 
 CamelOfflineJournal *
-camel_groupwise_journal_new (CamelGroupwiseFolder *folder, const gchar *filename)
+camel_groupwise_journal_new (CamelGroupwiseFolder *folder,
+                             const gchar *filename)
 {
 	CamelOfflineJournal *journal;
 
