@@ -188,7 +188,7 @@ proxy_get_password (EAccount *account,
 	CamelNetworkSecurityMethod security_method;
 	const gchar *poa_address;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (account->source->url, NULL);
 	if (url == NULL)
@@ -216,7 +216,7 @@ proxy_get_password (EAccount *account,
 
 	key = g_strdup_printf ("groupwise://%s@%s/", url->user, poa_address);
 
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, poa_address, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, poa_address, soap_port);
 
 	failed_auth = "";
 
@@ -244,7 +244,7 @@ proxy_login_get_cnc (EAccount *account,
 	const gchar *failed_auth;
 	gchar *uri = NULL, *key = NULL, *prompt = NULL, *password = NULL;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 	gboolean remember;
 
 	url = camel_url_new (account->source->url, NULL);
@@ -270,7 +270,7 @@ proxy_login_get_cnc (EAccount *account,
 		scheme = "https";
 
 	key = g_strdup_printf ("groupwise://%s@%s/", url->user, url->host);
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, url->host, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, url->host, soap_port);
 
 	failed_auth = "";
 	cnc = NULL;
@@ -282,7 +282,7 @@ proxy_login_get_cnc (EAccount *account,
 
 	if (!password)
 		password = e_passwords_ask_password (prompt, NULL, key, prompt,
-				E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET, &remember, password_dlg_parrent);
+				E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET, &remember, password_dlg_parrent);
 
 	g_free (prompt);
 	cnc = e_gw_connection_new (uri, url->user, password);
@@ -296,7 +296,9 @@ proxy_login_get_cnc (EAccount *account,
 }
 
 static void
-proxy_login_cb (GtkDialog *dialog, gint state, GtkWindow *parent)
+proxy_login_cb (GtkDialog *dialog,
+                gint state,
+                GtkWindow *parent)
 {
 	GtkWidget *account_name_tbox;
 	proxyLoginPrivate *priv;
@@ -324,7 +326,8 @@ proxy_login_cb (GtkDialog *dialog, gint state, GtkWindow *parent)
 }
 
 static void
-proxy_soap_login (gchar *email, GtkWindow *error_parent)
+proxy_soap_login (gchar *email,
+                  GtkWindow *error_parent)
 {
 	EAccountList *accounts = e_get_account_list ();
 	EAccount *srcAccount;
@@ -344,7 +347,7 @@ proxy_soap_login (gchar *email, GtkWindow *error_parent)
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
 	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
 
-	for (i=0; email[i]!='\0' && email[i]!='@' ; i++);
+	for (i = 0; email[i]!='\0' && email[i]!='@' ; i++);
 	if (email[i]=='@')
 		name = g_strndup (email, i);
 	else {
@@ -355,7 +358,7 @@ proxy_soap_login (gchar *email, GtkWindow *error_parent)
 	}
 
 	/* README: There should not be the weird scenario of the proxy itself configured as an account.
-	   If so, it is violating the (li) unix philosophy of User creation. So dont care about that scenario*/
+	 * If so, it is violating the (li) unix philosophy of User creation. So dont care about that scenario*/
 
 	if (itip_address_is_user (email)) {
 		e_alert_run_dialog_for_args (error_parent,
@@ -441,7 +444,7 @@ static void
 proxy_login_tree_view_changed_cb (GtkDialog *dialog)
 {
 	proxyLoginPrivate *priv = pld->priv;
-	GtkTreeSelection* account_select;
+	GtkTreeSelection * account_select;
 	GtkTreeIter iter;
 	GtkWidget *account_name_tbox;
 	GtkTreeModel *model;
@@ -455,7 +458,7 @@ proxy_login_tree_view_changed_cb (GtkDialog *dialog)
 	gtk_tree_model_get (model, &iter, ACCOUNT_NAME, &account_mailid, -1);
 	account_mailid = g_strrstr (account_mailid, "\n") + 1;
 	account_name_tbox = e_builder_get_widget (priv->builder, "account_name");
-	gtk_entry_set_text ((GtkEntry*) account_name_tbox,account_mailid);
+	gtk_entry_set_text ((GtkEntry *) account_name_tbox,account_mailid);
 }
 
 static void
@@ -503,9 +506,9 @@ proxy_login_update_tree (void)
 	gtk_tree_store_clear (priv->store);
 	if (proxy_list != NULL) {
 		n = g_list_length (proxy_list);
-		for (i=0;i<n;i=i+2) {
+		for (i = 0; i < n; i = i + 2) {
 			proxy_name = g_list_nth_data (proxy_list,i);
-			proxy_email = g_list_nth_data (proxy_list,i+1);
+			proxy_email = g_list_nth_data (proxy_list,i + 1);
 			gtk_tree_store_append (priv->store, &iter, NULL);
 			gtk_tree_store_set (priv->store, &iter, 0, broken_image, 1, g_strconcat(proxy_name, "\n", proxy_email, NULL), -1);
 		}
@@ -521,7 +524,8 @@ proxy_login_update_tree (void)
 }
 
 void
-gw_proxy_login_cb (GtkAction *action, EShellView *shell_view)
+gw_proxy_login_cb (GtkAction *action,
+                   EShellView *shell_view)
 {
 	EShellSidebar *shell_sidebar;
 	EMFolderTree *folder_tree = NULL;
