@@ -434,7 +434,7 @@ get_cnc (CamelStore *store)
 	CamelURL *url;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	if (!store)
 		return  NULL;
@@ -457,7 +457,7 @@ get_cnc (CamelStore *store)
 		scheme = "https";
 
 	uri = g_strdup_printf (
-		"%s://%s:%u/soap", scheme, server_name, soap_port);
+		"%s://%s:%s/soap", scheme, server_name, soap_port);
 
 	return e_gw_connection_new (uri, user, url->passwd);
 }
