@@ -167,7 +167,8 @@ e_gw_container_new_from_soap_parameter (SoupSoapParameter *param)
 }
 
 gboolean
-e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParameter *param)
+e_gw_container_set_from_soap_parameter (EGwContainer *container,
+                                        SoupSoapParameter *param)
 {
 	gchar *value;
 	gint int_value;
@@ -391,7 +392,8 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 }
 
 void
-e_gw_container_get_user_list (EGwContainer *container, GList **user_list)
+e_gw_container_get_user_list (EGwContainer *container,
+                              GList **user_list)
 {
 	g_return_if_fail (E_GW_CONTAINER (container));
 
@@ -408,7 +410,8 @@ e_gw_container_get_sequence (EGwContainer *container)
 }
 
 static  void
-e_gw_container_set_sequence (EGwContainer *container, gint sequence)
+e_gw_container_set_sequence (EGwContainer *container,
+                             gint sequence)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 	container->priv->sequence = sequence;
@@ -423,7 +426,8 @@ e_gw_container_get_modified (EGwContainer *container)
 }
 
 static void
-e_gw_container_set_modified (EGwContainer *container, const gchar *modified)
+e_gw_container_set_modified (EGwContainer *container,
+                             const gchar *modified)
 {
 	EGwContainerPrivate *priv;
 
@@ -438,12 +442,13 @@ e_gw_container_set_modified (EGwContainer *container, const gchar *modified)
 }
 
 static void
-e_gw_container_set_owner (EGwContainer *container, const gchar *owner)
+e_gw_container_set_owner (EGwContainer *container,
+                          const gchar *owner)
 {
 	EGwContainerPrivate *priv;
 
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
-	g_return_if_fail (owner!=NULL);
+	g_return_if_fail (owner != NULL);
 
 	priv = container->priv;
 	if (priv->owner)
@@ -460,7 +465,8 @@ e_gw_container_get_owner (EGwContainer *container)
 }
 
 gint
-e_gw_container_get_rights (EGwContainer *container, gchar *email)
+e_gw_container_get_rights (EGwContainer *container,
+                           gchar *email)
 {
 	GList *user_list = NULL;
 	GList *node = NULL;
@@ -488,7 +494,8 @@ e_gw_container_get_is_shared_by_me (EGwContainer *container)
 }
 
 static void
-e_gw_container_set_is_shared_by_me (EGwContainer *container, gboolean is_shared_by_me)
+e_gw_container_set_is_shared_by_me (EGwContainer *container,
+                                    gboolean is_shared_by_me)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 
@@ -504,7 +511,8 @@ e_gw_container_get_is_shared_to_me (EGwContainer *container)
 }
 
 static void
-e_gw_container_set_is_shared_to_me (EGwContainer *container, gboolean is_shared_to_me)
+e_gw_container_set_is_shared_to_me (EGwContainer *container,
+                                    gboolean is_shared_to_me)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 
@@ -520,7 +528,8 @@ e_gw_container_get_is_system_folder (EGwContainer *container)
 }
 
 void
-e_gw_container_set_is_system_folder (EGwContainer *container, gboolean is_system_folder)
+e_gw_container_set_is_system_folder (EGwContainer *container,
+                                     gboolean is_system_folder)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 
@@ -536,7 +545,8 @@ e_gw_container_get_name (EGwContainer *container)
 }
 
 void
-e_gw_container_set_name (EGwContainer *container, const gchar *new_name)
+e_gw_container_set_name (EGwContainer *container,
+                         const gchar *new_name)
 {
 	EGwContainerPrivate *priv;
 
@@ -559,7 +569,8 @@ e_gw_container_get_id (EGwContainer *container)
 }
 
 void
-e_gw_container_set_id (EGwContainer *container, const gchar *new_id)
+e_gw_container_set_id (EGwContainer *container,
+                       const gchar *new_id)
 {
 	EGwContainerPrivate *priv;
 
@@ -582,7 +593,8 @@ e_gw_container_get_parent_id (EGwContainer *container)
 }
 
 void
-e_gw_container_set_parent_id (EGwContainer *container, const gchar *parent_id)
+e_gw_container_set_parent_id (EGwContainer *container,
+                              const gchar *parent_id)
 {
 	EGwContainerPrivate *priv;
 
@@ -624,7 +636,8 @@ e_gw_container_get_is_writable (EGwContainer *container)
 }
 
 void
-e_gw_container_set_is_writable (EGwContainer *container, gboolean is_writable)
+e_gw_container_set_is_writable (EGwContainer *container,
+                                gboolean is_writable)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 
@@ -641,7 +654,8 @@ e_gw_container_get_is_frequent_contacts (EGwContainer *container)
 }
 
 void
-e_gw_container_set_is_frequent_contacts (EGwContainer *container, gboolean is_frequent_contacts)
+e_gw_container_set_is_frequent_contacts (EGwContainer *container,
+                                         gboolean is_frequent_contacts)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 
@@ -669,7 +683,12 @@ e_gw_container_get_container_type (EGwContainer *container)
  * flag = 0 :add to acl
  */
 void
-e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, const gchar *sub, const gchar *mesg, gint flag)
+e_gw_container_form_message (SoupSoapMessage *msg,
+                             gchar *id,
+                             GList *new_list,
+                             const gchar *sub,
+                             const gchar *mesg,
+                             gint flag)
 {
 	gboolean add, edit, del;
 	gchar *email = NULL;
@@ -689,7 +708,7 @@ e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, c
 
 		for (node = new_list; node != NULL; node = node->next) {
 			user = node->data;
-			add=edit=del=FALSE;
+			add = edit = del = FALSE;
 			soup_soap_message_start_element (msg, "entry", NULL, NULL);
 			e_gw_message_write_string_parameter (msg, "displayName", NULL,"");
 			email = g_strdup (user->email);
